@@ -11,40 +11,42 @@
 #define NEPOMUKHANDLER_H
 
 #include "kget_export.h"
-#include <nepomuk/resource.h>
+
 #include <QObject>
-#include <KUrl>
+#include <KFileItemList>
+
+namespace Nepomuk {
+    class Variant;
+}
+
 class Transfer;
 
 class KGET_EXPORT NepomukHandler : public QObject
 {
     Q_OBJECT
+
     public:
-        NepomukHandler(Transfer *transfer, QObject *parent);
-        ~NepomukHandler();
+        NepomukHandler(Transfer *transfer);
+        virtual ~NepomukHandler();
 
-        bool isValid();
-        QStringList tags() const;
-        int rating() const;
+        KFileItemList fileItems() const;
+
+        /**
+         * Sets properties to a list of files, if the list is empty m_destinations is used
+         */
+        void setProperties(const QList<QPair<QUrl, Nepomuk::Variant> > &properties, const QList<KUrl> &files = QList<KUrl>());
 
-    public slots:
-        void setRating(int rating);
-        void addTag(const QString &newTag);
-        void addTags(const QStringList &newTags);
-        void removeTag(const QString &oldTag);
         void saveFileProperties();
 
-    signals:
-        void validityChanged(bool isValid);
-
-    protected:
-        virtual void saveFileProperties(const Nepomuk::Resource &res);
+        /**
+         * Removes the resource if the isValid() is false
+         * @note call this method at the end of the deinit of the transfer,
+         * otherwise it might not work correctly
+         */
+        void deinit();
 
     private:
-        bool m_isValid;
         Transfer *m_transfer;
-        KUrl m_destination;
-        Nepomuk::Resource m_resource;
 };
 
 #endif
