@@ -25,6 +25,7 @@
 #include "core/transferhandler.h"
 #include "core/transfertreemodel.h"
 #include "core/basedialog.h"
+#include "settings.h"
 
 #include <QtCore/QFileInfo>
 
@@ -538,7 +539,12 @@ KUrl::List UrlChecker::hasExistingTransferMessages(const KUrl::List &urls, const
                     break;
                 }
 
-                const int result = hasExistingDialog(it->first, type, warning);
+                int result;
+                if (Settings::filesOverwrite() || (Settings::filesAutomaticRename() && (warning != ExistingTransfer))) {
+                    result = YesAll;
+                } else {
+                    result = hasExistingDialog(it->first, type, warning);
+                }
                 switch (result) {
                     case YesAll:
                         isYesAll = true;
@@ -696,6 +702,12 @@ KUrl UrlChecker::checkExistingFile(const KUrl &source, const KUrl &destination)
         return KUrl();
     }
 
+    if (Settings::filesOverwrite()) {
+        m_overwriteAll = true;
+    } else if (Settings::filesAutomaticRename()) {
+        m_autoRenameAll = true;
+    }
+
     if (wouldOverwrite(source, destination)) {
         KIO::RenameDialog_Mode args = static_cast<KIO::RenameDialog_Mode>(KIO::M_MULTI | KIO::M_SKIP | KIO::M_OVERWRITE);
         QScopedPointer<KIO::RenameDialog> dlg(new KIO::RenameDialog(KGet::m_mainWindow, i18n("File already exists"), source,
