@@ -15,6 +15,7 @@
 #include <cmath>
 
 #include <KDebug>
+#include <KLocale>
 
 #include <QtCore/QTimer>
 
@@ -184,8 +185,8 @@ void Segment::slotResult( KJob *job )
     {
         return;
     }
-    if (m_status == Running){
-        emit error(this, job->error());
+    if (job->error() && (m_status == Running)) {
+        emit error(this, job->errorString(), Transfer::Log_Error);
     }
 }
 
@@ -197,7 +198,8 @@ void Segment::slotData(KIO::Job *, const QByteArray& _data)
         kDebug(5001) << m_url << "does not allow resuming.";
         stopTransfer();
         setStatus(Killed, false );
-        emit error(this, KIO::ERR_CANNOT_RESUME);
+        const QString errorText = KIO::buildErrorString(KIO::ERR_CANNOT_RESUME, m_url.prettyUrl());
+        emit error(this, errorText, Transfer::Log_Warning);
         return;
     }
 
@@ -283,7 +285,7 @@ void Segment::slotWriteRest()
 
     if (++m_errorCount >= 100) {
         kWarning() << "Failed to write to the file:" << m_url << this;
-        emit error(this, KIO::ERR_COULD_NOT_WRITE);
+        emit error(this, i18n("Failed to write to the file."), Transfer::Log_Error);
     } else {
         kDebug() << "Wait 50 msec:" << this;
         QTimer::singleShot(50, this, SLOT(slotWriteRest()));
