@@ -75,11 +75,9 @@ NewTransferDialog::NewTransferDialog(QWidget *parent)
 
     ui.errorWidget->setCloseButtonVisible(false);
 
-    clear();
-
     connect(ui.groupComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(setDefaultDestination()));
 
-    connect(ui.urlRequester, SIGNAL(textChanged(QString)), this, SLOT(urlChanged(QString)));
+    connect(ui.urlRequester, SIGNAL(textChanged(QString)), this, SLOT(setDefaultDestination()));
     connect(ui.destRequester, SIGNAL(textChanged(QString)), this, SLOT(inputTimer()));
     connect(ui.urlRequester, SIGNAL(textChanged(QString)), this, SLOT(inputTimer()));
     connect(ui.listWidget, SIGNAL(itemChanged(QListWidgetItem*)), this, SLOT(inputTimer()));
@@ -104,19 +102,47 @@ void NewTransferDialog::setMultiple(bool useMultiple)
 void NewTransferDialog::clear()
 {
     ui.urlRequester->clear();
+    ui.urlRequester->setFocus();
     ui.listWidget->clear();
     ui.destRequester->comboBox()->clear();
     ui.destRequester->clear();
-    ui.groupComboBox->clear();
     m_destination.clear();
     m_sources.clear();
     m_existingTransfer = 0;
     m_overWriteSingle = false;
 
+    //add all destinations
+    QStringList list;
+    QString downloadPath = KGet::generalDestDir();
+    if (!downloadPath.isEmpty()) {
+        if (!downloadPath.endsWith('/')) {
+            downloadPath.append('/');
+        }
+        list << downloadPath;
+    }
+    foreach (TransferGroupHandler *handler, KGet::allTransferGroups()) {
+        const QString folder = handler->defaultFolder();
+        if (!folder.isEmpty()) {
+            list << (folder.endsWith('/') ? folder : folder + '/');
+        }
+    }
+
+    list.removeDuplicates();
+    ui.destRequester->comboBox()->insertItems(0, list);
+
+    //add all transfer groups
+    ui.groupComboBox->clear();
     foreach (TransferGroupHandler *group, KGet::allTransferGroups()) {
         ui.groupComboBox->addItem(KIcon(group->iconName()), group->name());
     }
-    ui.groupComboBox->setCurrentIndex(0);
+    ui.groupComboBox->setCurrentItem(Settings::lastGroup());
+    if (ui.groupComboBox->currentIndex() == -1) {
+        ui.groupComboBox->setCurrentIndex(0);
+    }
+
+    const bool multipleGroups = KGet::transferGroupNames().count();
+    ui.groupComboBox->setVisible(multipleGroups);
+    ui.groupLabel->setVisible(multipleGroups);
 }
 
 void NewTransferDialog::setSource(const KUrl::List &sources)
@@ -156,40 +182,8 @@ void NewTransferDialog::setDestinationFileName(const QString &filename)
     ui.destRequester->setUrl(QString(ui.destRequester->url().path(KUrl::AddTrailingSlash) + filename));
 }
 
-//TODO improve this method, so that it does not take sources and has a better name
-void NewTransferDialog::setDestination(const KUrl::List &sources, const QStringList &l)
+void NewTransferDialog::setDestination()
 {
-    Q_UNUSED(sources)
-
-    ui.destRequester->comboBox()->clear();
-    ui.destRequester->clear();
-
-    QStringList list = l;
-    kDebug(5001) << list;
-    QString filename = ui.destRequester->url().prettyUrl();
-
-    kDebug(5001) << "Seting destination :multiple=" << m_multiple << " and filename=" << filename;
-    if (!m_multiple) {
-        filename = m_destination.fileName();
-    } else if (!filename.isEmpty()) {
-        filename = m_destination.directory();
-    }
-
-    for (int i = 0; i < list.count(); ++i) {
-        if (!list.at(i).endsWith('/'))
-            list[i].append('/');
-        list[i].append(filename);
-    }
-
-    const QString downloadPath = KGet::generalDestDir();
-    if (!downloadPath.isEmpty()) {
-        list << downloadPath;
-    }
-    list.removeDuplicates();
-    kDebug(5001) << list;
-
-    ui.destRequester->comboBox()->insertItems(0, list);
-
     //sets destRequester to either display the defaultFolder of group or the generalDestDir
     QString group = ui.groupComboBox->currentText();
     TransferGroupHandler * current = 0;
@@ -199,20 +193,29 @@ void NewTransferDialog::setDestination(const KUrl::List &sources, const QStringL
             break;
         }
     }
-    if (current && !current->defaultFolder().isEmpty()) {
-        if (ui.destRequester->comboBox()->findText(current->defaultFolder()) == -1) {
-            ui.destRequester->comboBox()->addItem(current->defaultFolder());
+
+    if (current) {
+        QString groupFolder = current->defaultFolder();
+        if (groupFolder.isEmpty()) {
+            groupFolder = KGet::generalDestDir();
         }
-        ui.destRequester->comboBox()->setCurrentIndex(ui.destRequester->comboBox()->findText(current->defaultFolder()));
-    } else if (current) {
-        ui.destRequester->comboBox()->setCurrentIndex(ui.destRequester->comboBox()->findText(downloadPath));
+        if (!groupFolder.endsWith('/')) {
+            groupFolder.append('/');
+        }
+        ui.destRequester->comboBox()->setCurrentItem(groupFolder, true);
     }
 }
 
-void NewTransferDialog::showDialog(const KUrl::List &list, const QString &suggestedFileName)
+void NewTransferDialog::showDialog(KUrl::List list, const QString &suggestedFileName)
 {
+    //TODO handle the case where for some there are suggested file names --> own file name column in multiple setting
+    //the dialog is already in use, adapt it
+    if (isVisible()) {
+        list << m_sources;
+    }
     clear();//Let's clear the old stuff
     m_sources << list;
+    UrlChecker::removeDuplicates(m_sources);
     const int size = m_sources.size();
     kDebug(5001) << "SET SOURCES " << m_sources << " MULTIPLE " << (size > 1);
     setMultiple(size > 1);
@@ -225,34 +228,26 @@ void NewTransferDialog::showDialog(const KUrl::List &list, const QString &sugges
         setSource(m_sources);
     }
 
-    resizeDialog();
     prepareDialog();
 }
 
 void NewTransferDialog::setDefaultDestination()
 {
-    QStringList list;
-    foreach (TransferGroupHandler *handler, KGet::allTransferGroups()) {
-        if (!handler->defaultFolder().isEmpty())
-            list << handler->defaultFolder();
-    }
-    const QString fileName = ui.destRequester->url().fileName();
-    setDestination(m_sources, list);
-    if (!m_sources.isEmpty()) {
-        urlChanged(m_sources.first().path());
-        if (!m_multiple && !fileName.isEmpty()) {
-            KUrl url = ui.destRequester->url();
-            url.setFileName(fileName);
-            ui.destRequester->setUrl(url);
+    //NOTE if the user enters a file name manually and the changes the group the manually entered file name will be overwritten
+    setDestination();
+
+    //set a file name
+    if (!m_multiple) {
+        const KUrl url(ui.urlRequester->text().trimmed());
+        if ((UrlChecker::checkSource(url) == UrlChecker::NoError) &&
+            QFileInfo(ui.destRequester->url().toLocalFile()).isDir()) {
+            setDestinationFileName(url.fileName());
         }
     }
-    //d->setDestination(m_sources, KGet::defaultFolders(m_sources.first().path(), d->transferGroup()));
 }
 
 void NewTransferDialog::prepareDialog()
 {
-    setDefaultDestination();
-
     if (m_window) {
         KWindowInfo info = KWindowSystem::windowInfo(m_window->winId(), NET::WMDesktop, NET::WMDesktop);
         KWindowSystem::setCurrentDesktop(info.desktop());
@@ -263,37 +258,11 @@ void NewTransferDialog::prepareDialog()
     show();
 }
 
-/**
- * FIXME
- * The dialog is always lagging behind, i.e. if first m_multiple is false, then a small dialog will be displayed
- * if next m_multiple is true then still a small dialog will be displayed, then next dialog displayed no matter
- * if m_multiple is true will be large
-*/
-void NewTransferDialog::resizeDialog()
-{
-    if (KGet::transferGroupNames().count() < 2) {
-        ui.groupComboBox->hide();
-        ui.groupLabel->hide();
-    }
-}
-
 bool NewTransferDialog::isEmpty()
 {
     return (m_multiple ? !ui.listWidget->count() : ui.urlRequester->text().trimmed().isEmpty());
 }
 
-void NewTransferDialog::urlChanged(const QString &text)
-{
-    if (m_multiple) {
-        return;
-    }
-
-    KUrl url(text.trimmed());
-    if (QFileInfo(ui.destRequester->url().toLocalFile()).isDir()) {
-        setDestinationFileName(url.fileName());
-    }
-}
-
 void NewTransferDialog::inputTimer()
 {
     enableButtonOk(false);
@@ -485,6 +454,7 @@ void NewTransferDialog::dialogAccepted()
     }
 
     if (!data.isEmpty()) {
+        Settings::setLastGroup(ui.groupComboBox->currentText());
         KGet::createTransfers(data);
     }
 }
@@ -543,13 +513,19 @@ void NewTransferDialogHandler::showNewTransferDialog(KUrl::List urls)
     ///Only two urls defined, check if second one is a path or a file name
     if (urls.count() == 2) {
         const KUrl lastUrl = urls.last();
+        QDir dir(lastUrl.toLocalFile());
 
         //check if last url is a file path, either absolute or relative
         if (lastUrl.isLocalFile()) {
             if (QDir::isAbsolutePath(lastUrl.toLocalFile())) {
-                //second url is a file path, use this one
-                folder = lastUrl.directory(KUrl::AppendTrailingSlash);
-                suggestedFileName = lastUrl.fileName();
+                if (dir.exists()) {
+                    //second url is a folder path
+                    folder = lastUrl.path(KUrl::AddTrailingSlash);
+                } else {
+                    //second url is a file path, use this one
+                    folder = lastUrl.directory(KUrl::AppendTrailingSlash);
+                    suggestedFileName = lastUrl.fileName();
+                }
                 urls.removeLast();
             } else {
                 //second url is just a file name
