@@ -2,6 +2,7 @@
     videodevicepool.h  -  Kopete Multiple Video Device handler Class
 
     Copyright (c) 2005-2006 by Cláudio da Silveira Pinheiro   <taupter@gmail.com>
+    Copyright (c) 2010      by Frank Schaefer                 <fschaefer.oss@googlemail.com>
 
     Kopete    (c) 2002-2003      by the Kopete developers  <kopete-devel@kde.org>
 
@@ -22,11 +23,8 @@
 
 
 #include "videoinput.h"
-#include "videodevicemodelpool.h"
 #include <qstring.h>
 #include <qimage.h>
-#include <q3valuevector.h>
-#include <qmutex.h>
 #include <kcombobox.h>
 #include "videodevice.h"
 #include "kopete_export.h"
@@ -34,6 +32,7 @@
 #include <kglobal.h>
 #include <solid/device.h>
 
+
 namespace Kopete {
 
 namespace AV {
@@ -44,66 +43,72 @@ This class allows kopete to check for the existence, open, configure, test, set
 @author Cláudio da Silveira Pinheiro
 */
 
-typedef QVector<Kopete::AV::VideoDevice> VideoDeviceVector;
-
-
 class KOPETE_EXPORT VideoDevicePool : public QObject
 {
+
 Q_OBJECT
+
 public:
 	static VideoDevicePool* self();
-	int open();
-	int open(int device);
+	~VideoDevicePool();
 	bool isOpen();
+	int open( int device = -1 );
+	int close();
+
+	int size();
+	int currentDevice();
+	QString currentDeviceUdi();
+	int inputs();
+	int currentInput();
+	int selectInput( int newinput );
+
+	QList<NumericVideoControl> getSupportedNumericControls();
+	QList<BooleanVideoControl> getSupportedBooleanControls();
+	QList<MenuVideoControl> getSupportedMenuControls();
+	QList<ActionVideoControl> getSupportedActionControls();
+	int getControlValue( quint32 ctrl_id, qint32 * value );
+	int setControlValue( quint32 ctrl_id, qint32 value );
+
+	int startCapturing();
+	int stopCapturing();
 	int getFrame();
+	int getImage( QImage *qimage );
+
 	int width();
 	int minWidth();
 	int maxWidth();
 	int height();
 	int minHeight();
 	int maxHeight();
-	int setSize( int newwidth, int newheight);
-	int close();
-	int startCapturing();
-	int stopCapturing();
-	int readFrame();
-	int getImage(QImage *qimage);
-	int selectInput(int newinput);
-	int setInputParameters();
-	int scanDevices();
-	void registerDevice( Solid::Device & dev );
-	bool hasDevices();
-	size_t size();
-	~VideoDevicePool();
-	VideoDeviceVector m_videodevice; // Vector to be filled with found devices
-	VideoDeviceModelPool m_modelvector;  // Vector to be filled with unique device models
-	int fillDeviceKComboBox(KComboBox *combobox);
-	int fillInputKComboBox(KComboBox *combobox);
-	int fillStandardKComboBox(KComboBox *combobox);
-	int currentDevice();
-	int currentInput();
-	unsigned int inputs();
+	int setImageSize( int newwidth, int newheight );
 
-	float getBrightness();
-	float setBrightness(float brightness);
-	float getContrast();
-	float setContrast(float contrast);
-	float getSaturation();
-	float setSaturation(float saturation);
-	float getWhiteness();
-	float setWhiteness(float whiteness);
-	float getHue();
-	float setHue(float hue);
+	void fillDeviceKComboBox( KComboBox *combobox );
+	void fillInputKComboBox( KComboBox *combobox );
+	void fillStandardKComboBox( KComboBox *combobox );
 
-	bool getAutoBrightnessContrast();
-	bool setAutoBrightnessContrast(bool brightnesscontrast);
-	bool getAutoColorCorrection();
-	bool setAutoColorCorrection(bool colorcorrection);
-	bool getImageAsMirror();
-	bool setImageAsMirror(bool imageasmirror);
+	void saveCurrentDeviceConfig();
 
-	void loadConfig(); // Load configuration parameters;
-	void saveConfig(); // Save configuretion parameters;
+protected:
+	int m_current_device;
+	QVector<VideoDevice*> m_videodevices;	/*!< Vector of pointers to the available video devices */
+
+	bool registerDevice( Solid::Device & dev );
+	int showDeviceCapabilities( int device = -1 );
+	int getSavedDevice();
+	void loadDeviceConfig();
+
+private:
+	static VideoDevicePool* s_self;
+	static __u64 m_clients; // Number of instances
+
+	VideoDevicePool();
+
+protected slots:
+	/**
+	 * Slot called when a new device is added to the system
+	 */
+	void deviceAdded( const QString & udi );
+	void deviceRemoved( const QString & udi );
 
 signals:
 	/**
@@ -111,25 +116,7 @@ signals:
 	 */
 	void deviceRegistered( const QString & udi );
 	void deviceUnregistered( const QString & udi );
-protected slots:
-	/**
-	 * Slot called when a new device is added to the system
-	 */
-	void deviceAdded( const QString & udi );
-	void deviceRemoved( const QString & udi );
-protected:
-	int xioctl(int request, void *arg);
-	int errnoReturn(const char* s);
-	int showDeviceCapabilities(unsigned int device);
-	void guessDriver();
-	int m_current_device;
-	struct imagebuffer m_buffer; // only used when no devices were found
 
-	QMutex m_ready;
-private:
-	VideoDevicePool();
-	static VideoDevicePool* s_self;
-	static __u64 m_clients; // Number of instances
 };
 
 }
