@@ -17,20 +17,38 @@
 
 #include "kopetepasswordwidget.h"
 #include "kopetepassword.h"
+#include "kopeteprotocol.h"
 
-#include <kpassdlg.h>
+#include <klineedit.h>
 
 #include <qcheckbox.h>
 
-class Kopete::UI::PasswordWidget::Private
+namespace Kopete
 {
-public:
-	uint maxLength;
-};
+	namespace UI
+	{
+		class PasswordWidget::Private
+		{
+			public:
+				Private() : protocol( 0 ) { }
+				Kopete::Protocol * protocol;
+		};
+	} // namespace UI
+} // namespace Kopete
 
-Kopete::UI::PasswordWidget::PasswordWidget( QWidget *parent, const char *name, Kopete::Password *from )
- : KopetePasswordWidgetBase( parent, name ), d( new Private )
+Kopete::UI::PasswordWidget::PasswordWidget( QWidget *parent )
+	    : QWidget( parent ), d( new Private )
 {
+	setupUi( this );
+	mPassword->setPasswordMode(true);
+}
+
+Kopete::UI::PasswordWidget::PasswordWidget( Kopete::Password *from, QWidget *parent )
+	: QWidget( parent ), d( new Private )
+{
+	setupUi( this );
+	mPassword->setPasswordMode(true);
+
 	load( from );
 }
 
@@ -39,33 +57,35 @@ Kopete::UI::PasswordWidget::~PasswordWidget()
 	delete d;
 }
 
+void Kopete::UI::PasswordWidget::setValidationProtocol( Kopete::Protocol * proto )
+{
+	d->protocol = proto;
+}
+
 void Kopete::UI::PasswordWidget::load( Kopete::Password *source )
 {
 	disconnect( mRemembered, SIGNAL( stateChanged( int ) ), this, SLOT( slotRememberChanged() ) );
-	disconnect( mPassword, SIGNAL( textChanged( const QString & ) ), this, SIGNAL( changed() ) );
+	disconnect( mPassword, SIGNAL( textChanged( const QString & ) ),
+			this, SLOT( passwordTextChanged() ) );
 	disconnect( mRemembered, SIGNAL( stateChanged( int ) ), this, SIGNAL( changed() ) );
 
 	if ( source && source->remembered() )
 	{
 		mRemembered->setTristate();
-		mRemembered->setNoChange();
+		mRemembered->setCheckState( Qt::PartiallyChecked );
+		mPassword->setEnabled( true );
 		source->requestWithoutPrompt( this, SLOT( receivePassword( const QString & ) ) );
 	}
 	else
 	{
 		mRemembered->setTristate( false );
-		mRemembered->setChecked( false );
+		mRemembered->setCheckState( Qt::Unchecked );
+		mPassword->setEnabled( false );
 	}
 
-	if ( source )
-		d->maxLength = source->maximumLength();
-	else
-		d->maxLength = 0;
-
-	mPassword->setEnabled( false );
-
 	connect( mRemembered, SIGNAL( stateChanged( int ) ), this, SLOT( slotRememberChanged() ) );
-	connect( mPassword, SIGNAL( textChanged( const QString & ) ), this, SIGNAL( changed() ) );
+	connect( mPassword, SIGNAL( textChanged( const QString & ) ),
+			this, SLOT( passwordTextChanged() ) );
 	connect( mRemembered, SIGNAL( stateChanged( int ) ), this, SIGNAL( changed() ) );
 
 	emit changed();
@@ -81,7 +101,7 @@ void Kopete::UI::PasswordWidget::receivePassword( const QString &pwd )
 {
 	// pwd == null could mean user declined to open wallet
 	// don't uncheck the remembered field in this case.
-	if ( !pwd.isNull() && mRemembered->state() == QButton::NoChange )
+	if ( !pwd.isNull() && mRemembered->checkState() == Qt::PartiallyChecked )
 	{
 		mRemembered->setChecked( true );
 		setPassword( pwd );
@@ -90,9 +110,9 @@ void Kopete::UI::PasswordWidget::receivePassword( const QString &pwd )
 
 void Kopete::UI::PasswordWidget::save( Kopete::Password *target )
 {
-	if ( !target || mRemembered->state() == QButton::NoChange )
+	if ( !target || mRemembered->checkState() == Qt::PartiallyChecked )
 		return;
-	
+
 	if ( mRemembered->isChecked() )
 		target->set( password() );
 	else
@@ -101,19 +121,25 @@ void Kopete::UI::PasswordWidget::save( Kopete::Password *target )
 
 bool Kopete::UI::PasswordWidget::validate()
 {
-	if ( !mRemembered->isChecked() ) return true;
-	if ( d->maxLength == 0 ) return true;
-	return password().length() <= d->maxLength;
+	// Unchecked means the password should not be remembered, partially checked 
+	// we're waiting for kwallet. Let it pass in both cases.
+	if ( mRemembered->checkState() != Qt::Checked )
+		return true;
+
+	if ( d->protocol ) {
+		return d->protocol->validatePassword( password() );
+	}
+	return true;
 }
 
 QString Kopete::UI::PasswordWidget::password() const
 {
-	return QString::fromLocal8Bit( mPassword->password() );
+	return mPassword->text();
 }
 
 bool Kopete::UI::PasswordWidget::remember() const
 {
-	return mRemembered->state() == QButton::On;
+	return mRemembered->checkState() == Qt::Checked;
 }
 
 void Kopete::UI::PasswordWidget::setPassword( const QString &pass )
@@ -122,11 +148,24 @@ void Kopete::UI::PasswordWidget::setPassword( const QString &pass )
 	mRemembered->setTristate( false );
 
 	// fill in the password text
-	mPassword->erase();
-	mPassword->insert( pass );
+	mPassword->clear();
+	mPassword->setText( pass );
 	mPassword->setEnabled( remember() );
 }
 
+void Kopete::UI::PasswordWidget::passwordTextChanged()
+{
+	if ( mRemembered->checkState() == Qt::PartiallyChecked )
+	{
+		disconnect( mRemembered, SIGNAL( stateChanged( int ) ), this, SIGNAL( changed() ) );
+		// switch out of 'waiting for wallet' mode if we're in it
+		mRemembered->setTristate( false );
+		mRemembered->setChecked(true);
+		connect( mRemembered, SIGNAL( stateChanged( int ) ), this, SIGNAL( changed() ) );
+	}
+	emit changed();
+}
+
 #include "kopetepasswordwidget.moc"
 
 // vim: set noet ts=4 sts=4 sw=4:
