@@ -19,6 +19,7 @@
     *************************************************************************
 */
 
+#include "gwaccount.h"
 #include <sys/utsname.h>
 
 #include <qvalidator.h>
@@ -30,7 +31,7 @@
 #include <kinputdialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kpassivepopup.h>
+#include <knotification.h>
 #include <kactionmenu.h>
 
 #include <kopeteuiglobal.h>
@@ -63,8 +64,6 @@
 #include "ui/gwprivacydialog.h"
 #include "ui/gwreceiveinvitationdialog.h"
 
-#include "gwaccount.h"
-
 GroupWiseAccount::GroupWiseAccount( GroupWiseProtocol *parent, const QString& accountID, const char *name )
 : Kopete::PasswordedAccount ( parent, accountID )
 {
@@ -210,7 +209,7 @@ GroupWiseChatSession * GroupWiseAccount::findChatSessionByGuid( const GroupWise:
 
 GroupWiseContact * GroupWiseAccount::contactForDN( const QString & dn )
 {
-	QHashIterator<QString, Kopete::Contact*> i( contacts() );
+	QHashIterator<QString, Kopete::Contact*> i( contacts() ); // FIXME: what about myself??
 	// check if we have a DN for them
 	while ( i.hasNext() )
 	{
@@ -371,7 +370,7 @@ void GroupWiseAccount::slotMessageSendingFailed()
 				i18nc("Message Sending Failed using the named local account", "Kopete was not able to send the last message sent on account '%1'.\nIf possible, please send the console output from Kopete to <wstephenson@novell.com> for analysis.", accountId() ) , i18nc("message sending failed using the named local account", "Unable to Send Message on Account '%1'", accountId() ) );
 }
 
-void GroupWiseAccount::setOnlineStatus( const Kopete::OnlineStatus& status, const Kopete::StatusMessage &reason )
+void GroupWiseAccount::setOnlineStatus( const Kopete::OnlineStatus& status, const Kopete::StatusMessage &reason, const OnlineStatusOptions& options )
 {
 	kDebug () ;
 	if ( status == protocol()->groupwiseUnknown
@@ -522,8 +521,6 @@ void GroupWiseAccount::reconcileOfflineChanges()
 	while( it.hasNext() )
 	{
 		it.next();
-		if ( it.value() == myself() )
-			continue;
 
 		GroupWiseContact * c = static_cast< GroupWiseContact *>( it.value() );
 		kDebug() << "  reconciling changes for: '" << c->contactId() << "'";
@@ -586,7 +583,7 @@ void GroupWiseAccount::reconcileOfflineChanges()
 	} //end while, now check the next groupwise contact
 	if ( conflicts )
 		// show queuedmessagebox
-		KPassivePopup::message( i18n( "Conflicting Changes Made Offline" ), i18n( "A change happened to your GroupWise contact list while you were offline which was impossible to reconcile." ), Kopete::UI::Global::mainWidget() );
+		KNotification::event(KNotification::Warning, i18n( "Kopete: Conflicting Changes Made Offline" ), i18n( "A change happened to your GroupWise contact list while you were offline which was impossible to reconcile." ), QPixmap(), Kopete::UI::Global::mainWidget() );
 	m_dontSync = false;
 }
 
@@ -1318,7 +1315,7 @@ void GroupWiseAccount::receiveContactDeleted( const ContactItem & instance )
 
 void GroupWiseAccount::slotConnectedElsewhere()
 {
-	KPassivePopup::message( i18n ( "Signed in as %1 Elsewhere", accountId() ), i18nc(  "The parameter is the user's own account id for this protocol", "You have been disconnected from GroupWise Messenger because you signed in as %1 elsewhere", accountId() ) , Kopete::UI::Global::mainWidget() );
+	KNotification::event(KNotification::Notification, i18n ( "Kopete: Signed in as %1 Elsewhere", accountId() ), i18nc(  "The parameter is the user's own account id for this protocol", "You have been disconnected from GroupWise Messenger because you signed in as %1 elsewhere", accountId() ) , QPixmap(), Kopete::UI::Global::mainWidget() );
 	disconnect();
 }
 
