@@ -18,11 +18,13 @@
 #ifndef USERDETAILSMANAGER_H
 #define USERDETAILSMANAGER_H
 
-#include <qmap.h>
-#include <qobject.h>
-#include <qstringlist.h>
+#include <QMap>
+#include <QObject>
+#include <QStringList>
 
 #include "gwerror.h"
+#include "libgroupwise_export.h"
+
 class Client;
 
 /**
@@ -31,11 +33,11 @@ Several client event handling processes require that a contact's details are ava
 @author SUSE AG
 */
 
-class UserDetailsManager : public QObject
+class LIBGROUPWISE_EXPORT UserDetailsManager : public QObject
 {
 Q_OBJECT
 public:
-	UserDetailsManager( Client * parent, const char *name = 0);
+	UserDetailsManager( Client * parent);
 	~UserDetailsManager();
 	/**
 	 * List of DNs that we have already received details for
@@ -51,7 +53,7 @@ public:
 	ContactDetails details( const QString &dn );
 	/** 
 	 * Add a ContactDetails object to our cache.
-	 * This SHOULD be called when receiving details in contactlist receive and manipulation, to prevent unnecessary additional requests.
+	 * This SHOULD be called when receiving details in contact list receive and manipulation, to prevent unnecessary additional requests.
 	 */
 	void addDetails( const GroupWise::ContactDetails & details );
 	/**
