@@ -14,8 +14,6 @@
   * *                                                                       *
   * *************************************************************************
   */
-#include <KDebug>
-#include <QMessageBox>
 
 //Kopete
 #include "jabberjinglecontent.h"
@@ -28,6 +26,9 @@
 #include "jinglecontent.h"
 #include "jinglesession.h"
 
+#include <KDebug>
+#include <QMessageBox>
+
 JabberJingleContent::JabberJingleContent(JabberJingleSession* parent, XMPP::JingleContent* c)
  : m_content(c), m_jabberSession(parent)
 {
@@ -46,14 +47,10 @@ JabberJingleContent::JabberJingleContent(JabberJingleSession* parent, XMPP::Jing
 JabberJingleContent::~JabberJingleContent()
 {
 	kDebug() << "destroyed";
-	if (m_content)
-		delete m_content;
-	if (m_rtpInSession)
-		delete m_rtpInSession;
-	if (m_rtpOutSession)
-		delete m_rtpOutSession;
-	if (m_mediaSession)
-		delete m_mediaSession;
+	delete m_content;
+	delete m_rtpInSession;
+	delete m_rtpOutSession;
+	delete m_mediaSession;
 }
 
 void JabberJingleContent::setContent(XMPP::JingleContent* content)
