@@ -131,6 +131,46 @@ void ReceiveFileTask::slotData( KIO::Job *job, const QByteArray& data )
 	
 }
 
+
+void ReceiveFileTask::slotHeadComplete( KJob *job )
+{
+	kDebug(YAHOO_RAW_DEBUG) ;
+
+	KIO::TransferJob *transfer = static_cast< KIO::TransferJob * >(job);
+
+	bool got_error = job->error () || transfer->isErrorPage ();
+
+	/* SEEME:
+	   Following check disabled for now because Yahoo is sending a non http conforming answer ('\r\n' and *then* the HTTP response headers.
+	   That makes kio slave http not want to read more and parse the headers. 
+	   So.. leaving this comment here until yahoo is sending a correct http response so that we can correctly check if the HEAD cmd
+	   succeeded.
+        */
+#if 0
+	if (!got_error)
+	{
+		got_error = transfer->queryMetaData(QLatin1String("HTTP-Headers")).length() <= 5; // I was getting 2 bytes in such error cases.
+	}
+#endif
+	if (got_error)
+	{
+		emit error( m_transferId, KIO::ERR_ABORTED, i18n("An error occurred while downloading the file.") );
+		setError();
+	}
+	else
+	{
+		// same URL from the HEAD cmd
+		m_transferJob = KIO::get( transfer->url(), KIO::Reload, KIO::HideProgressInfo );
+
+		QObject::connect( m_transferJob, SIGNAL( result( KJob* ) ), this, SLOT( slotComplete( KJob* ) ) );
+		QObject::connect( m_transferJob, SIGNAL( data( KIO::Job*, const QByteArray & ) ), this, SLOT( slotData( KIO::Job*, const QByteArray & ) ) );
+
+        	setCommonTransferMetaData(m_transferJob);
+	}
+	m_mimetypeJob = 0;
+}
+
+
 void ReceiveFileTask::slotComplete( KJob *job )
 {
 	kDebug(YAHOO_RAW_DEBUG) ;
@@ -149,6 +189,7 @@ void ReceiveFileTask::slotComplete( KJob *job )
 		emit complete( m_transferId );
 		setSuccess();
 	}
+	m_transferJob = 0;
 }
 
 void ReceiveFileTask::parseFileTransfer7Info( YMSGTransfer *transfer )
@@ -188,23 +229,36 @@ void ReceiveFileTask::parseFileTransfer7Info( YMSGTransfer *transfer )
 	
 		send( t );
 		// The server expects a HTTP HEAD command prior to the GET
-		m_mimetypeJob = KIO::mimetype(QString::fromLatin1("http://%1/relay?token=%2&sender=%3&recver=%4")
-				.arg( QString(transfer->firstParam( 250 )) ).arg( QString(transfer->firstParam( 251 )) ).arg(m_userId).arg(client()->userId()), false);
+		m_mimetypeJob = KIO::mimetype(QString(
+				QString::fromLatin1("http://%1/relay?token=")
+					.arg( QString(transfer->firstParam( 250 )) ) 
+				+
+				QString(QUrl::toPercentEncoding(QString(transfer->firstParam( 251 )))) +
+				QString::fromLatin1("&sender=%1&recver=%2")
+					.arg(m_userId)
+					.arg(client()->userId()))
+				, 
+				KIO::HideProgressInfo);
 		m_mimetypeJob->addMetaData("cookies", "manual");
-		m_mimetypeJob->addMetaData("setcookies", QString::fromLatin1("Cookie: T=%1; path=/; domain=.yahoo.com; Y=%2; C=%3;")
-				.arg(client()->tCookie()).arg(client()->yCookie()).arg(client()->cCookie()) );
+		setCommonTransferMetaData(m_mimetypeJob);
+		QObject::connect( m_mimetypeJob, SIGNAL( result( KJob* ) ), this, SLOT( slotHeadComplete( KJob* ) ) );
 
-
-		m_transferJob = KIO::get( QString::fromLatin1("http://%1/relay?token=%2&sender=%3&recver=%4")
-				.arg( QString(transfer->firstParam( 250 )) ).arg( QString(transfer->firstParam( 251 )) ).arg(m_userId).arg(client()->userId()), KIO::NoReload, KIO::HideProgressInfo );
-		QObject::connect( m_transferJob, SIGNAL( result( KJob* ) ), this, SLOT( slotComplete( KJob* ) ) );
-		QObject::connect( m_transferJob, SIGNAL( data( KIO::Job*, const QByteArray & ) ), this, SLOT( slotData( KIO::Job*, const QByteArray & ) ) );
-		m_transferJob->addMetaData("cookies", "manual");
- 		m_transferJob->addMetaData("setcookies", QString::fromLatin1("Cookie: T=%1; path=/; domain=.yahoo.com; Y=%2;  path=/; domain=.yahoo.com;")
- 				.arg(client()->tCookie()).arg(client()->yCookie()) );
 	}
 }
 
+
+void ReceiveFileTask::setCommonTransferMetaData(KIO::TransferJob* job)
+{
+	job->addMetaData(QString::fromLatin1("accept"), "*/*"); // Accept header
+	job->addMetaData(QString::fromLatin1("UserAgent"), "Mozilla/5.0");
+	job->addMetaData(QString::fromLatin1("cache"), "reload");
+
+	job->addMetaData("cookies", "manual");
+ 	job->addMetaData("setcookies", QString::fromLatin1("Cookie: T=%1; Y=%2;")
+ 				.arg(client()->tCookie()).arg(client()->yCookie()) );
+}
+
+
 void ReceiveFileTask::setRemoteUrl( KUrl url )
 {
 	m_remoteUrl = url;
@@ -234,9 +288,17 @@ void ReceiveFileTask::canceled( unsigned int id )
 {
 	if( m_transferId != id )
 		return;
-	
+
+	if( m_mimetypeJob )
+	{
+		m_mimetypeJob->kill();
+		m_mimetypeJob = 0L;
+	}
 	if( m_transferJob )
+	{
 		m_transferJob->kill();
+		m_transferJob = 0L;
+	}
 	
 	setError();
 }
