@@ -2,7 +2,7 @@
  *
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppdata.h,v 1.82 2004/07/11 06:09:24 porten Exp $
+ * $Id: pppdata.h 728852 2007-10-24 13:08:37Z ossi $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -22,7 +22,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef _PPPDATA_H_
@@ -34,10 +34,10 @@
 #include <qstring.h>
 #include <qstringlist.h>
 #include <qcolor.h>
+#include <ksharedconfig.h>
 
 #include "kpppconfig.h"
 
-class KConfig;
 
 // string lengths
 
@@ -168,7 +168,7 @@ class KConfig;
 class PPPData {
 public:
   PPPData();
-  ~PPPData() {};
+  ~PPPData() {}
 
   enum { NumInitStrings = 2 };
 
@@ -181,12 +181,10 @@ public:
   // function to read/write date to configuration file
   QString readConfig(const QString &, const QString &, const QString &);
   int readNumConfig(const QString &, const QString &, int);
-  bool readListConfig(const QString &, const QString &,
-                      QStringList &, char sep = ',');
+  bool readListConfig(const QString &, const QString &, QStringList &);
   void writeConfig(const QString &, const QString &, const QString &);
   void writeConfig(const QString &, const QString &, int);
-  void writeListConfig(const QString &, const QString &,
-                       QStringList &, char sep = ',');
+  void writeListConfig(const QString &, const QString &, QStringList &);
 
   // return the current account group
   QString currentAccountGroup() { return caccountgroup; }
@@ -491,7 +489,7 @@ public:
 
 private:
   QString passwd;
-  KConfig* config;                       // configuration object
+  KSharedConfig::Ptr config;                       // configuration object
   int accounthighcount;                  // index of highest account
   int caccount;                          // index of the current account
 	int modemhighcount;                    // index of highest modem
