@@ -2,7 +2,7 @@
  *
  *            Kppp: A pppd front end for the KDE project
  *
- * $Id: pwentry.cpp,v 1.10 2004/10/25 20:36:48 bmeyer Exp $
+ * $Id: pwentry.cpp 704673 2007-08-25 18:53:49Z amth $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -20,18 +20,25 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
 
 #include <stdio.h>
 #include <qapplication.h>
+//Added by qt3to4:
+#include <QFocusEvent>
+#include <QResizeEvent>
 #include <kglobalsettings.h>
 #include "pwentry.h"
 
+#ifdef __GNUC__
+#warning A null parent is a weird choice. Any reason?
+#endif
 PWEntry::PWEntry( QWidget *parent, const char *name )
-	: QWidget(NULL, name) {
+	: QWidget(NULL) {
+   setObjectName(name);
 
    if(parent){
 
@@ -47,15 +54,16 @@ PWEntry::PWEntry( QWidget *parent, const char *name )
      setGeometry( desk.center().x() - 150, desk.center().y() - 50, 300, 90 );
    }
 
-   frame = new QGroupBox(name, this );
+   frame = new Q3GroupBox(name, this );
    
-   setFocusPolicy( QWidget::StrongFocus );
+   setFocusPolicy( Qt::StrongFocus );
    
-   pw = new QLineEdit( this, "le" );
+   pw = new QLineEdit( this );
+   pw->setObjectName( "le" );
    pw->setEchoMode( QLineEdit::Password ); 
    connect( pw, SIGNAL(returnPressed()), this, SLOT(hide()) );
 
-   isconsumed = TRUE;
+   isconsumed = true;
 }
 
 QString PWEntry::text() { return (pw->text()); }
@@ -95,7 +103,7 @@ void PWEntry::resizeEvent(QResizeEvent* ){
 void PWEntry::show() {
 
     pw->setText("");
-    isconsumed = FALSE;
+    isconsumed = false;
     QWidget::show();
 }
 
@@ -104,7 +112,7 @@ bool PWEntry::Consumed() {
 }
 
 void PWEntry::setConsumed() {
-    isconsumed = TRUE;
+    isconsumed = true;
 }
 
 void PWEntry::hide() {
