@@ -1,7 +1,7 @@
 /* -*- C++ -*-
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: ruleset.h,v 1.12 2003/03/07 22:06:51 waba Exp $
+ * $Id: ruleset.h 704683 2007-08-25 19:55:14Z amth $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -21,19 +21,19 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef __RULESET__H__
 #define __RULESET__H__
 
-#include <qmemarray.h>
+
 #include <qdatetime.h>
 #include <qstring.h>
-
+#include <QVector>
 // this structure is used to save
 // accounting rules
-typedef struct RULE {
+typedef struct {
   int type;
   double costs;
   double len;
@@ -45,7 +45,7 @@ typedef struct RULE {
   struct {
     int from, until;
   } weekday;
-};
+} RULE;
 
 // this class is used for loading and parsing of rules
 class RuleSet {
@@ -54,7 +54,7 @@ public:
   RuleSet();
 
   /// gcc needs a destructor (otherwise compiler error)
-  ~RuleSet() {};
+  ~RuleSet() {}
 
   /// returns the name of the ruleset
   QString name() const;
@@ -76,7 +76,7 @@ public:
   QString currencyString(double val) const;
 
   /// sets the start time -- must be called when the connection has bee established
-  void setStartTime(QDateTime dt);
+  void setStartTime(const QDateTime &dt);
 
   /// returns the "per-connection" costs
   double perConnectionCosts() const;
@@ -87,7 +87,7 @@ public:
   double minimumCosts() const;
 
   /// returns the currently valid rule settings
-  void getActiveRule(QDateTime dt, double connect_time, double &costs, double &len);
+  void getActiveRule(const QDateTime &dt, double connect_time, double &costs, double &len);
 
   /// checks if a rulefile is ok (no parse errors...)
   static int checkRuleFile(const QString &);
@@ -140,7 +140,7 @@ protected:
   double flat_init_duration;
   double flat_init_costs;
 
-  QMemArray<RULE> rules;
+  QVector<RULE> rules;
 };
 
 #endif
